@@ -1,6 +1,6 @@
-from shared import InfoHolder, CameraVariable
-from logger import Logger
-from connections import ConnectionHelper
+from .shared import InfoHolder, CameraVariable
+from .logger import Logger
+from .connections import ConnectionHelper
 import signal
 
 
@@ -12,6 +12,10 @@ class Shufflecad:
         signal.signal(signal.SIGINT, cls.handler)
         ConnectionHelper.init_and_start()
 
+    @classmethod
+    def stop(cls):
+        ConnectionHelper.stop()
+
     @classmethod
     def add_var(cls, var):
         if type(var) == CameraVariable:
